@@ -8,13 +8,14 @@
 ## 2014-09-03 implemented userdist
 ## 2015-01-31 average all trap locations for default start in fxi.mode
 ## 2015-02-19 sessnum bug in fxi.contour fixed
+## 2015-10-11 mark-resight included
 ###############################################################################
 
 fxi.secr <- function (object, i = 1, sessnum = 1, X, normal = TRUE, ncores = 1) {
 
 # Return scaled Pr(wi|X).pi(X) for one nominated detection history,
 # where X holds coordinates of points
-
+    
     ##--------------------------------------------------------------------
     ## in multi-session case must get session-specific data from lists
     if (ms(object)) {
@@ -60,9 +61,6 @@ fxi.secr <- function (object, i = 1, sessnum = 1, X, normal = TRUE, ncores = 1)
     if (any(is.na(i) | (i<1) | (i>nrow(session.capthist))))
         stop ("invalid i in fxi.secr")
 
-    if (details$scalesigma | details$scaleg0)
-        stop ("fxi.secr does not implement scaled sigma or g0")
-
     if (object$detectfn == 11)
         stop ("fxi.secr does not work with spherical spreading at present")
 
@@ -132,6 +130,14 @@ fxi.secr <- function (object, i = 1, sessnum = 1, X, normal = TRUE, ncores = 1)
     }
     else
         session.signal <- 0
+    
+    
+    ##############################################################################
+    ## prepare mark-resight data 2015-10-11,15,17
+    MRdata <- markresight(session.capthist, session.mask, object$CL, object$fixed,
+                          object$details$chat, sessnum) 
+    ##############################################################################
+    
 
     ## miscparm is used to package beta parameters that are not modelled
     ## and hence do not have a beta index specified by parindx.
@@ -197,7 +203,6 @@ fxi.secr <- function (object, i = 1, sessnum = 1, X, normal = TRUE, ncores = 1)
                    as.double(piX),
                    as.integer(object$CL),         # 0 = full, 1 = CL
                    as.integer(dettype),           # 0 = multicatch, 1 = proximity, etc
-                   as.integer(details$param),     # 0 = Borchers & Efford, 1 Gardner & Royle
                    as.integer(session.capthist),
                    as.double(unlist(session.xy)),
                    as.double(session.signal),
@@ -213,6 +218,9 @@ fxi.secr <- function (object, i = 1, sessnum = 1, X, normal = TRUE, ncores = 1)
                    as.double(distmat),            ## optional dist2 2014-08-27, 2014-09-03
                    as.double(distmatX),           ## optional dist2 2014-08-27, 2014-09-03
                    as.double(usge),
+                   as.integer(MRdata$markocc),
+                   as.integer(MRdata$Tu),
+                   as.integer(MRdata$Tm),
                    as.double(unlist(session.mask)),
                    as.double(pimask),             ## strictly needed here only if normal>0
                    as.double(Xrealparval),
@@ -231,9 +239,10 @@ fxi.secr <- function (object, i = 1, sessnum = 1, X, normal = TRUE, ncores = 1)
     }
 
     if ((ncores > 1) & (length(i) > 1)) {
-        clust <- makeCluster(ncores, methods = TRUE)
+        clust <- makeCluster(ncores, methods = FALSE, useXDR = .Platform$endian=='big')
+        clusterEvalQ(clust, requireNamespace('secr'))
         output <- parLapply(clust, i, fxone)
-        on.exit(stopCluster(clust))
+        stopCluster(clust)
     }
     else {
         output <- if (length(i) > 1)
@@ -268,7 +277,6 @@ fxi2SPDF <- function (x, ID, levels) {
 fxi.contour <- function (object, i = 1, sessnum = 1, border = 100, nx = 64,
     levels = NULL, p = seq(0.1,0.9,0.1), plt = TRUE, add = FALSE, fitmode =
     FALSE, plotmode = FALSE, normal = TRUE, fill = NULL, SPDF = FALSE,  ncores = 1, ...) {
-
     if (inherits(object$mask, 'linearmask'))
         stop("contouring fxi is not appropriate for linear habitat")
     if (ms(object)) {
@@ -384,28 +392,56 @@ fxi.mode <- function (object, i = 1, sessnum = 1, start = NULL, ...) {
 ## mask if specified should be for a single session
 ## ... passes newdata df to predict.secr
 
-fx.total <- function (object, sessnum = 1, mask = NULL, ncores = 1, ...) {
-    if (ms(object)) stop ("not for ms model")
-    n <- nrow(object$capthist)
-    if (is.null(mask))
-        mask <- if (ms(object)) object$mask[[sessnum]] else object$mask
+## upgraded 2015-06-20
+## fx.total <- function (object, sessnum = 1, mask = NULL, ncores = 1, ...) {
+##     if (ms(object)) stop ("not for ms model")
+##     n <- nrow(object$capthist)
+##     if (is.null(mask))
+##         mask <- if (ms(object)) object$mask[[sessnum]] else object$mask
+## 
+##     ## sum of individual fxi
+##     fxi <- fxi.secr(object, i = 1:n, sessnum = sessnum, X = mask, normal = TRUE, ncores = ncores)
+##     fx <- do.call(cbind, fxi)
+##     fxt <- apply(fx, 1, sum)
+##     fxt <- fxt / getcellsize(mask)   ## length or area 2014-09-10
+## 
+##     ## predicted uncaught animals
+##     D <- predictDsurface(object, mask = mask)
+##     if (ms(object)) D <- D[[sessnum]]
+##     D <- covariates(D)$D.0
+##     CH <- if (ms(object)) object$capthist[[sessnum]] else object$capthist
+##     pd <- pdot(X = mask, traps = traps(CH), detectfn = object$detectfn,
+##                detectpar = detectpar(object, ...), noccasions = ncol(CH))
+##     nct <- D * (1 - pd)
+## 
+##     covariates(mask) <- data.frame(D.fx = fxt, D.nc = nct, D.sum = fxt + nct)
+##     class(mask) <- c('Dsurface', class(mask))
+##     mask
+## }
 
-    ## sum of individual fxi
-    fxi <- fxi.secr(object, i = 1:n, sessnum = sessnum, X = mask, normal = TRUE, ncores = ncores)
+fx.total <- function (object, sessnum = 1, mask = NULL, ncores = 1, ...) 
+{
+    n <- if (ms(object)) nrow(object$capthist[[sessnum]])   
+    else nrow(object$capthist)
+    if (is.null(mask)) 
+        mask <- if (ms(object)) object$mask[[sessnum]]
+            else object$mask
+    fxi <- fxi.secr(object, i = 1:n, sessnum = sessnum, X = mask, 
+        normal = TRUE, ncores = ncores)
     fx <- do.call(cbind, fxi)
     fxt <- apply(fx, 1, sum)
-    fxt <- fxt / getcellsize(mask)   ## length or area 2014-09-10
-
-    ## predicted uncaught animals
+    fxt <- fxt/getcellsize(mask)
     D <- predictDsurface(object, mask = mask)
-    if (ms(object)) D <- D[[sessnum]]
     D <- covariates(D)$D.0
-    CH <- if (ms(object)) object$capthist[[sessnum]] else object$capthist
-    pd <- pdot(X = mask, traps = traps(CH), detectfn = object$detectfn,
-               detectpar = detectpar(object, ...), noccasions = ncol(CH))
+    CH <- if (ms(object)) 
+        object$capthist[[sessnum]]
+    else object$capthist
+    pd <- pdot(X = mask, traps = traps(CH), detectfn = object$detectfn, 
+        detectpar = detectpar(object, ...), noccasions = ncol(CH))
     nct <- D * (1 - pd)
-
-    covariates(mask) <- data.frame(D.fx = fxt, D.nc = nct, D.sum = fxt + nct)
-    class(mask) <- c('Dsurface', class(mask))
+    covariates(mask) <- data.frame(D.fx = fxt, D.nc = nct, D.sum = fxt + 
+        nct)
+    class(mask) <- c("Dsurface", class(mask))
     mask
 }
+
